[commit: ghc] wip/spj-early-inline2: Stop uniques ending up in SPEC rule names (368d882)

git at git.haskell.org git at git.haskell.org
Tue Feb 21 23:26:49 UTC 2017


Repository : ssh://git@git.haskell.org/ghc

On branch  : wip/spj-early-inline2
Link       : http://ghc.haskell.org/trac/ghc/changeset/368d882c66a8f85d16e91fb42930e45c39cfc342/ghc

>---------------------------------------------------------------

commit 368d882c66a8f85d16e91fb42930e45c39cfc342
Author: Simon Peyton Jones <simonpj at microsoft.com>
Date:   Tue Feb 14 13:33:36 2017 +0000

    Stop uniques ending up in SPEC rule names


>---------------------------------------------------------------

368d882c66a8f85d16e91fb42930e45c39cfc342
 compiler/specialise/Specialise.hs | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/compiler/specialise/Specialise.hs b/compiler/specialise/Specialise.hs
index 0090417..3f937c2 100644
--- a/compiler/specialise/Specialise.hs
+++ b/compiler/specialise/Specialise.hs
@@ -1293,10 +1293,11 @@ specCalls mb_mod env rules_for_me calls_for_me fn rhs
                            Just this_mod  -- Specialising imoprted fn
                                -> text "SPEC/" <> ppr this_mod
 
-                rule_name = mkFastString $ showSDocForUser dflags neverQualify $
-                            herald <+> ppr fn <+> hsep (map ppr_call_key_ty call_ts)
-                            -- This name ends up in interface files, so use showSDocForUser,
-                            -- otherwise uniques end up there, making builds
+                rule_name = mkFastString $ showSDoc dflags $
+                            herald <+> text (occNameString (getOccName fn))
+                                   <+> hsep (map ppr_call_key_ty call_ts)
+                            -- This name ends up in interface files, so use occNameString.
+                            -- Otherwise uniques end up there, making builds
                             -- less deterministic (See #4012 comment:61 ff)
 
                 rule_wout_eta = mkRule



More information about the ghc-commits mailing list